# vim: set fileencoding=utf-8 :
#
# Copyright (c) 2013 Daniel Truemper <truemped at googlemail.com>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
from __future__ import absolute_import, division, print_function, with_statement

from supercell.api.metatypes import (ContentType, MediaType, Return, Ok,
                                     Error, OkCreated)
from supercell.api.requesthandler import RequestHandler
from supercell.api.decorators import provides, consumes, async, cache
from supercell.api.service import Service


__all__ = [
    'async',
    'cache',
    'ContentType',
    'MediaType',
    'RequestHandler',
    'provides',
    'consumes',
    'Return',
    'Ok',
    'OkCreated',
    'Error',
    'Service',
]
